@@ -365,7 +365,8 @@ def get_inv_b2_coeffs(ll, uu, dll, duu, c_l, c_u):
     a[ind_z2] = b[ind_z2] = 0.0
     #c = 1.0/min_val + d * argmin * min_val**-2 + d**2 * argmin ** 2 * min_val**-3
     c = ((d * argmin / min_val + 1) * d * argmin / min_val + 1.0)/min_val
-    c[ind_z2] = 1.0/min_val[ind_z2]# - (a * argmin + b) * argmin
+    c[logical_or(ind_z, ind_z2)] = 1.0/min_val[ind_z]
+    #c[ind_z2] = 1.0/min_val[ind_z2]# - (a * argmin + b) * argmin
     koeffs_l = (a, b, c)
     
     #U
@@ -386,7 +387,7 @@ def get_inv_b2_coeffs(ll, uu, dll, duu, c_l, c_u):
 #    c[ind_z2] = inv_l2
     
     koeffs_u = array((a, b, c))
-#    print koeffs_l, koeffs_u
+    
     return koeffs_l, koeffs_u
 
 def pow_const_interval(self, r, other, domain, dtype):
@@ -516,21 +517,20 @@ def pow_const_interval(self, r, other, domain, dtype):
     return Tmp, definiteRange    
 
 def inv_b_interval(B, revert):
-    
+    if type(B) == boundsurf2:
+        B = B.to_linear()
+        
     k = list(B.dep)[0]
     l, u = B.domain[k]
     d_l, d_u = B.l.d[k], B.u.d[k]
     c_l, c_u = B.l.c, B.u.c 
+        
     if revert:
-#            print('revert')
-#            B = -B
         d_l, d_u = -d_u, -d_l
         c_l, c_u = -c_u, -c_l
 
-#        print B_resolved
-#        print l, u, d_l, d_u, c_l, c_u
     koeffs_l, koeffs_u = get_inv_b2_coeffs(l, u, d_l, d_u, c_l, c_u)
-    
+
 #        ###########
 #        from boundsurf2 import apply_quad_lin
 #        a, b, c = koeffs_l
@@ -622,10 +622,12 @@ def pow_b_interval(lb_ub, r1, other):
     U = surf2({k:a}, {k:b}, c)
 #########################
 #    from numpy import linspace
+#    #l = 0.99
+#    print l, u
 #    x = linspace(l, u, 10000)
 #    import pylab
-#    pylab.plot(x, pow(d_l*x+c_l), 'b', linewidth = 2)
-#    pylab.plot(x, pow(d_u*x+c_u), 'r', linewidth = 2)
+#    pylab.plot(x, pow(d_l*x+c_l, other), 'b', linewidth = 2)
+#    pylab.plot(x, pow(d_u*x+c_u, other), 'r', linewidth = 2)
 #    pylab.plot(x, koeffs_l[0]*x**2+koeffs_l[1]*x+koeffs_l[2], 'b', linewidth = 1)
 #    pylab.plot(x, koeffs_u[0]*x**2+koeffs_u[1]*x+koeffs_u[2], 'r', linewidth = 1)
 #    pylab.show()
@@ -638,6 +640,7 @@ def pow_b_interval(lb_ub, r1, other):
     return R, definiteRange
     
 def pow_interval(r, inp, other, domain, dtype):
+#    other = 1.9
     lb_ub, definiteRange = inp._interval(domain, dtype, ia_surf_level = 2)
     
     #!!!!! Temporary !!!!
@@ -647,6 +650,7 @@ def pow_interval(r, inp, other, domain, dtype):
     if ia_lvl_2_unavailable or is_b2:
         from ooFun import oofun
         r1, definiteRange = oofun._interval_(r, domain, dtype)
+        #return r1, definiteRange
     else:
         r1 = None
     
